@@ -249,7 +249,7 @@ async def create_all(pool):
         pool: Connection pool to the database in which to create the SQL tables.
     """
 
-    await db_execute(pool, 'CREATE SCHEMA data;')
+    await db_execute(pool, 'CREATE SCHEMA IF NOT EXISTS data;')
     await db_execute(
         pool, 'CREATE EXTENSION IF NOT EXISTS "uuid-ossp"'
         ' WITH SCHEMA data;')
