@@ -496,7 +496,8 @@ class Collection(Resource):
             if col_name == 'id':
                 id_name = id_number_to_name(value)
             elif col_name in self.table.attributes_by_name:
-                attributes[col_name] = value
+                attr = self.table.attributes_by_name[col_name]
+                attributes[col_name] = attr.type_.from_sql(value)
             else:  # col_name is a lfkey
                 rel = self.table.relationship_by_lfkey[col_name]
                 if value:
